
# Class: example


usage example and description

URI: [linkml:Example](https://w3id.org/linkml/Example)


[![img](images/Example.svg)](images/Example.svg)

## Referenced by Class

 *  **[Element](Element.md)** *[examples](examples.md)*  <sub>0..\*</sub>  **[Example](Example.md)**

## Attributes


### Own

 * [value](value.md)  <sub>0..1</sub>
     * Description: example value
     * Range: [String](types/String.md)
 * [example➞description](value_description.md)  <sub>0..1</sub>
     * Description: description of what the value is doing
     * Range: [String](types/String.md)
